pecos.qeclib.steane.qec
=======================

.. automodule:: pecos.qeclib.steane.qec



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.qeclib.steane.qec.qec_3parallel
